@@ -26,12 +26,14 @@ import Vitalus.utils as utils
 import datetime
 import logging
 from contextlib import closing
-
+import socket
 
 class TARGETError(Exception):
     """
     Exception for target validity
+
     :param message: Message
+    :type message: string
     """
     def __init__(self, message=''):
         Exception.__init__(self, message)
@@ -42,6 +44,9 @@ class Target:
     A target is a source or a destination.
     Both of them can be a local directory
     or a distant one though SSH
+
+    :param target: a target
+    :type target: string
     """
     def __init__(self, target):
         self.logger = logging.getLogger('Vitalus.Target')
@@ -53,12 +58,13 @@ class Target:
             self.path = target
         elif self.is_ssh():
             self.login, self.path = target.split(':')
+            self.domain = self.login.split('@')[1]
 
     def is_dir(self):
         """
         Check if the target is a directory
 
-        :returns: boolean
+        :returns: bool -- True if it is a directory
         """
         if self.ttype == 'DIR':
             return True
@@ -69,20 +75,38 @@ class Target:
         """
         Check if the target is a 'SSH' host
 
-        :returns: boolean
+        :returns: bool -- True if it is a SSH host
         """
         if self.ttype == 'SSH':
             return True
         else:
             return False
 
+    def check_availability(self):
+        """
+        Check if the target is available
+        For SSH host, it means it's reachable
+
+        :returns: bool -- True is available
+        """
+        if self.ttype == 'SSH':
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            try:
+                sock.connect((self.domain, 22))
+            except socket.error:
+                raise TARGETError("Target %s unreachable" % self.target)
+            else:
+                return True
+        elif self.ttype == 'DIR':
+            pass #TODO
+
+
     def _detect_target_type(self):
         """
         Return the target type
         SSH if matches name@domaine.tld:dir
         DIR if it's a directory
 
-        :param target: Target (source or destination)
         :raises TARGETError: weird target type
         """
         #if re.match('[a-zA-Z0-9+_\-\.]+@[0-9a-zA-Z][.-0-9a-zA-Z]*.[a-zA-Z]+\:.*', self.target):
@@ -104,22 +128,30 @@ class Job:
     """
     Class containing a job
 
-    :param min_disk_space: minimal disk space
     :param log_dir: Log directory path
+    :type log_dir: string
     :param name: Job name
+    :type name: string
     :param source: Source path
+    :type source: string
     :param destination: Destination path
+    :type destination: string
     :param period: Min duration between two backups (in seconds)
-    :param snapshot: Activate snapshots (Boolean)
+    :type period: float
+    :param snapshot: Activate snapshots
+    :type snapshot: bool
     :param duration: How many days snapshots are kept
+    :type duration: int
     :param keep: How many snapshots are (at least) kept
+    :type keep: int
     :param filter: Rsync filters
+    :type filter: list
 
 
-    Note:
-    -----
-    Source and destination path can be either real path
-    or a ssh login joined to the path by a : caracter.
+    .. note::
+
+        Source and destination path can be either real path
+        or a ssh login joined to the path by a : character.
     """
 
     def __init__(self, log_dir, name, source, destination, period, snapshot, duration, keep, filter):
@@ -213,32 +245,33 @@ class Job:
         Delete old archives in the destination
 
         :param days: delete files older than this value
+        :type days: int
         :param keep: keep at least this amount of archives
+        :type keep: int
         """
         #TODO : review logs
 
         path = os.path.join(self.destination.path, self.name)
 
+        self.destination.check_availability()
         if self.destination.is_dir():
-            #filenames = [os.path.join(path, el) for el in os.listdir(path) ]
             filenames = os.listdir(path)
         elif self.destination.is_ssh():
-            command = ['ssh', '-t', self.destination.login, 'ls', '-1', path]
-            self.logger.debug('SSH ls command: ' + str(command))
-            process = subprocess.Popen(command, bufsize=4096, stdout=subprocess.PIPE)
-            stdout, stderr = process.communicate()
-            filenames = stdout.decode()
-            filenames = filenames.split('\n')
-            filenames = [x.strip('\r') for x in filenames if x!='']
+                command = ['ssh', '-t', self.destination.login, 'ls', '-1', path]
+                self.logger.debug('SSH ls command: ' + str(command))
+                process = subprocess.Popen(command, bufsize=4096, stdout=subprocess.PIPE)
+                stdout, stderr = process.communicate()
+                filenames = stdout.decode()
+                filenames = filenames.split('\n')
+                filenames = [x.strip('\r') for x in filenames if x!='']
         else:
             return
 
-        self.logger.debug("file_list %s ", filenames)
-
         to_delete = utils.get_older_files(filenames, days, keep)
+        self.logger.debug("Backups available %s ", filenames)
+        self.logger.debug("Backups to delete %s ", to_delete)
 
-        self.logger.debug("to delete %s ", to_delete)
-
+        self.destination.check_availability()
         if self.destination.is_dir():
             for element in to_delete:
                 self.logger.debug("Remove backup %s", element)
@@ -264,6 +297,7 @@ class Job:
         :returns: string
         """
         path = os.path.join(self.destination.path, self.name)
+        self.destination.check_availability()
         if self.destination.is_dir():
             if not os.path.isdir(path):
                 return None
@@ -296,6 +330,7 @@ class Job:
         Prepare the destination to receive a backup:
         Create dirs
         """
+        self.destination.check_availability()
         if self.destination.is_dir():
             if self.snapshot:
                 os.makedirs(self.current_backup_path) # This one does not exist!
@@ -364,11 +399,14 @@ class Job:
     def _run_command(self, command):
         """
         Run a command and log stderr+stdout in a dedicated log file.
-        :param command: a list, each element is a part of the command line
 
-        Example
-        -------
-        command = ['/usr/bin/cp', '-r', '/home', '/tmp']
+        :param command: Command: each element is a part of the command line
+        :type command: list
+
+        .. note::
+
+            Example of the command format
+            command = ['/usr/bin/cp', '-r', '/home', '/tmp']
         """
         #Run the command
         process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
@@ -390,55 +428,56 @@ class Job:
         #TODO rewriting and integration:
         #self._check_disk_usage()
 
-        last_date = self._get_last_backup()
-        self.current_backup_path = os.path.join(self.destination.path, self.name, str(self.current_date))
-        if last_date is None:
-            #It means that this is the first backup.
-            self.previous_backup_path = None
-        else:
-            #self.previous_backup_path = os.path.join(self.destination.path, self.name, str(last_date))
-            self.previous_backup_path = last_date
+        try:
+            last_date = self._get_last_backup()
+            self.current_backup_path = os.path.join(self.destination.path, self.name, str(self.current_date))
+            if last_date is None:
+                #It means that this is the first backup.
+                self.previous_backup_path = None
+            else:
+                #self.previous_backup_path = os.path.join(self.destination.path, self.name, str(last_date))
+                self.previous_backup_path = last_date
 
-        self.logger.debug("Previous backup path: %s", self.previous_backup_path)
-        self.logger.debug("Current backup path: %s", self.current_backup_path)
+            self.logger.debug("Previous backup path: %s", self.previous_backup_path)
+            self.logger.debug("Current backup path: %s", self.current_backup_path)
 
-        if self._check_need_backup():
-            self.job_logger.info('='*20 + str(self.now) + '='*20)
-            self.logger.debug('Start Backup: %s', self.name)
-            print(self.name)
+            if self._check_need_backup():
+                self.job_logger.info('='*20 + str(self.now) + '='*20)
+                self.logger.debug('Start Backup: %s', self.name)
+                print(self.name)
 
-            # Prepare the destination
-            self._prepare_destination()
-            self.logger.debug("source path %s", self.source.target)
-            self.logger.debug("destination path %s", self.destination.target)
-            self.logger.debug("filter path %s", self.filter)
+                # Prepare the destination
+                self._prepare_destination()
+                self.logger.debug("source path %s", self.source.target)
+                self.logger.debug("destination path %s", self.destination.target)
+                self.logger.debug("filter path %s", self.filter)
 
-            # Run rsync
-            command = self._prepare_rsync_command()
-            self._run_command(command)
+                # Run rsync
+                command = self._prepare_rsync_command()
+                self._run_command(command)
 
-            # Job done, update the time in the database
-            self._set_lastbackup_time()
+                # Job done, update the time in the database
+                self._set_lastbackup_time()
 
-            # Remove old snapshots
-            self._delete_old_files(days=10, keep=10) # TODO adjustable in API
-
-            # Create symlink
-            last = os.path.join(self.destination.path, self.name, 'last')
-            if self.destination.is_dir():
-                if os.path.islink(last):
-                    os.remove(last)
-                os.chdir(os.path.dirname(self.current_backup_path))
-                try:
-                    os.symlink(os.path.basename(self.current_backup_path), last)
-                except FileExistsError:
-                    self.logger.warning('The symlink %s could not be created because a file exists', last)
-                except AttributeError:
-                    self.logger.warning('Attribute error for symlink. Job: %s', self.name)
-            elif self.destination.is_ssh():
-                pass
-                #TODO Create symlink
-
-            self.logger.info("Backup %s done", self.name)
+                # Remove old snapshots
+                self._delete_old_files(days=10, keep=10) # TODO adjustable in API
 
+                # Create symlink
+                last = os.path.join(self.destination.path, self.name, 'last')
+                if self.destination.is_dir():
+                    if os.path.islink(last):
+                        os.remove(last)
+                    os.chdir(os.path.dirname(self.current_backup_path))
+                    try:
+                        os.symlink(os.path.basename(self.current_backup_path), last)
+                    except FileExistsError:
+                        self.logger.warning('The symlink %s could not be created because a file exists', last)
+                    except AttributeError:
+                        self.logger.warning('Attribute error for symlink. Job: %s', self.name)
+                elif self.destination.is_ssh():
+                    pass
+                    #TODO Create symlink
 
+                self.logger.info("Backup %s done", self.name)
+        except TARGETError as e:
+            self.logger.warning(e)
